| GeoNetwork-class | R Documentation |
An S4 class object with the multiple components resulting from a geographical habitat network analysis.
The GeoNetwork object will wrap all the results from the habitat connectivity analysis using sean() or sensitivity_analysis().
Specifically, this class contains the field from Gmap class, which has results of the habitat connectivity analysis in the form of SpatRaster and TIFF file.
## S4 replacement method for signature 'GeoNetwork'
habitat_density(x) <- value
x |
GeoNetwork. |
value |
SpatRaster. |
GeoNetwork.
rastersA list of GeoRasters objects.
habitat_densityA SpatRaster representing the habitat availability (or simply host density) that was used as input in the habitat connectivity analysis.
me_rastA SpatRaster representing the mean habitat connectivity of a region. The mean is calculated based on a sensitivity analysis across the user-specified dispersal parameters.
me_outCharacter. A file path to where the mean habitat connectivity raster is saved.
diff_rastA SpatRaster representing the difference in ranks between the mean habitat connectivity and the user-supplied map of habitat availability.
diff_outCharacter. A file path to where the difference raster is saved.
var_rastA SpatRaster representing the variance in habitat connectivity in a region. The variance is calculated based on a sensitivity analysis across the user-specified dispersal parameters.
var_outCharacter. A file path to where the variance raster is saved.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.