GlobalRast-class: GlobalRast class

GlobalRast-classR Documentation

GlobalRast class

Description

A class to represent raster objects for global scales. Global scales are accessible using global_scales(). However, this class encapsulates the results of apply dispersal models and metrics.

Fields

east

A list of raster objects for eastern hemisphere.

west

A list of raster objects for western hemisphere.


geohabnet documentation built on May 26, 2026, 9:06 a.m.