Gmap-class: Gmap class

Gmap-classR Documentation

Gmap class

Description

An S4 class object to organize various maps in the form of SpatRaster in a single object.

Usage

setmaps(x, me, vari, dif)

Arguments

x

Gmap. Please provide a Gmap object.

me

SpatRaster. A SpatRaster used as background when plotting the map of mean habitat connectivity.

vari

SpatRaster. A Spatraster used as background when plotting the map of variance in habitat connectivity.

dif

SpatRaster. A raster used as background when plotting the map of difference in habitat connectivity and habitat availability.

Value

Gmap object.

Slots

me_rast

A SpatRaster object representing habitat connectivity of a region averaged across all selected parameters.

me_out

Character. A file path to where the mean habitat connectivity is saved.

diff_rast

A SpatRaster object representing the difference in ranks between mean habitat connectivity and habitat availability in a region.

diff_out

Character. A file path to where the difference raster is saved.

var_rast

A SpatRaster object representing the variance in habitat connectivity of a region calculated across all specified parameters.

var_out

Character. A file path to where the variance raster is saved.


geohabnet documentation built on May 26, 2026, 9:06 a.m.