| get_parameters | R Documentation |
This function retrieves the list of parameters and saves a copy of the parameter file (of type .yaml) to the specified output path.
get_parameters(out_path = tempdir(), iwindow = FALSE)
out_path |
character. The output path where the parameter file will be
copied. The default is a temporary directory |
iwindow |
logical. If window = |
Using this configuration where the parameters are structurally listed in
a yaml file is an alternative method used in the sensitivity_analysis()
function. Once the parameter.yaml is saved in a local directory, the user can
modify each parameter value, save this file with the changes, and get the
new parameters back in R with set_parameters().
Note that the sean() or msean() function will require to directly list
the parameters within the function as it is typical in other R packages.
character. The path to the copied parameter file.
set_parameters()
get_parameters()
get_parameters(out = tempdir())
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.