habitat_density-set: Set the habitat density.

habitat_density<-R Documentation

Set the habitat density.

Description

This function helps to set a SpatRaster of the habitat availability or density in a GeoNetwork object. The function is an S4 replacement method in the geohabnet package. It allows you to assign a host availability SpatRaster to a geohabnet object.

Usage

habitat_density(x) <- value

Arguments

x

the GeoNetwork object.

value

SpatRaster.

Value

The same object type as x, that is, GeoNetwork. This function returns the updated S4 GeoNetwork object with the new habitat availability SpatRaster assigned.


geohabnet documentation built on May 26, 2026, 9:06 a.m.