| hci_diff | R Documentation |
This function produces a map of the difference in ranks between mean habitat connectivity and habitat availability.
hci_diff(x, y, global, geoscale, res = reso(), outdir = tempdir(), plt = TRUE)
x |
SpatRaster. |
y |
SpatRaster. |
global |
Logical. Select |
geoscale |
Numeric vector. |
res |
Numeric. This parameter refers to the spatial aggregation factor. This value is the number of cells that are grouped when aggregating a raster layer from fine to coarse spatial resolution to reduce computational costs. Setting this parameter to 1 would not aggregate the raster layers.
Default is |
outdir |
Character. Output directory for saving raster in TIFF format.
Default is |
plt |
|
Ideally, the function is tested to yield desired results when
length(which(y[] > 0)) > length(which(x[] > 0)).
RiskMap. Contains result in the form of SpatRaster objects
and file path of the saved maps.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.