| hci_variance | R Documentation |
This function produces a map of variance of habitat connectivity across selected parameter values
hci_variance(
indices,
rast,
global,
east = NULL,
west = NULL,
geoscale,
res = reso(),
outdir = tempdir(),
plt = TRUE
)
indices |
SpatRaster. Collection of risk indices. |
rast |
SpatRaster. Template for variance output |
global |
Logical. Select |
east |
SpatRaster. Collection of risk indices on eastern extent. |
west |
SpatRaster. Collection of risk indices on western extent.
When |
geoscale |
Vector. This refers to the geographical extent for the habitat connectivity analysis when |
res |
Numeric. This parameter refers to the spatial aggregation factor. This value is the number of cells that are grouped when aggregating a raster layer from fine to coarse spatial resolution to reduce computational costs. Setting this parameter to 1 would not aggregate the raster layers.
Default is |
outdir |
Character. Output directory for saving raster in TIFF format.
Default is |
plt |
|
RiskMap. Contains result in the form of SpatRaster objects
and file path of the saved maps.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.