| setprops | R Documentation |
Set properties of the GeoModel object.
setprops(x, aggregation, hdthreshold, linkthreshold)
x |
The GeoModel object. |
aggregation |
Character. A value representing the spatial aggregation method used for aggregating the habitat availability map before conducting the sensitivity analysis. There are two aggregation methods available in geohabnet: sum and/or mean, either excludes NaNs during aggregation. |
hdthreshold |
Numeric. A numeric value representing the threshold for habitat availability (e.g., cropland density or host density) used in the sensitivity analysis. |
linkthreshold |
Numeric. A numeric value representing the threshold for the link weights used to calculate habitat connectivity of each location. Note that link weights indicate the relative likelihood of a species moving between locations (nodes) and correspond to the entries in the adjacency matrix. |
The GeoModel object with updated properties.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.