| Gmap-class | R Documentation |
An S4 class object to organize various maps in the form of SpatRaster in a single object.
setmaps(x, me, vari, dif)
x |
Gmap. Please provide a |
me |
SpatRaster. A SpatRaster used as background when plotting the map of mean habitat connectivity. |
vari |
SpatRaster. A Spatraster used as background when plotting the map of variance in habitat connectivity. |
dif |
SpatRaster. A raster used as background when plotting the map of difference in habitat connectivity and habitat availability. |
Gmap object.
me_rastA SpatRaster object representing habitat connectivity of a region averaged across all selected parameters.
me_outCharacter. A file path to where the mean habitat connectivity is saved.
diff_rastA SpatRaster object representing the difference in ranks between mean habitat connectivity and habitat availability in a region.
diff_outCharacter. A file path to where the difference raster is saved.
var_rastA SpatRaster object representing the variance in habitat connectivity of a region calculated across all specified parameters.
var_outCharacter. A file path to where the variance raster is saved.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.