| habitat_density<- | R Documentation |
This function helps to set a SpatRaster of the habitat availability or density in a GeoNetwork object. The function is an S4 replacement method in the geohabnet package. It allows you to assign a host availability SpatRaster to a geohabnet object.
habitat_density(x) <- value
x |
the GeoNetwork object. |
value |
SpatRaster. |
The same object type as x, that is, GeoNetwork. This function returns the updated S4 GeoNetwork object with the new habitat availability SpatRaster assigned.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.